import typer
from rich.console import Console
from rich.table import Table
from peter_parquet.cliparquet import CLIParquet

console = Console()
app = typer.Typer()

@app.command()
def schema(file: str = typer.Option(..., "--file", "-f")):
    peter = CLIParquet(parquet_path=file)
    console.print(peter.schema())
    
@app.command()
def metadata(file: str = typer.Option(..., "--file", "-f"),
             column: str = typer.Option(None, "--column", "-c")):
    peter = CLIParquet(parquet_path=file, column=column)
    console.print(peter.metadata())

@app.command()
def head(file: str = typer.Option(..., "--file", "-f"),
         column: str = typer.Option(None, "--column", "-c"),
         n: int = typer.Option(5, "--nrows", "-n")):
    peter = CLIParquet(parquet_path=file, column=column)
    console.print(peter.head(n))

@app.command()
def tail(file: str = typer.Option(..., "--file", "-f"),
         column: str = typer.Option(None, "--column", "-c"),
         n: int = typer.Option(5, "--nrows", "-n")):
    peter = CLIParquet(parquet_path=file, column=column)
    console.print(peter.tail(n))

@app.command()
def cat(file: str = typer.Option(..., "--file", "-f"),
        column: str = typer.Option(None, "--column", "-c")):
    peter = CLIParquet(parquet_path=file, column=column)
    console.print(peter.cat())

@app.command()
def not_null(file: str = typer.Option(..., "--file", "-f"),
        column: str = typer.Option(None, "--column", "-c")):
    peter = CLIParquet(parquet_path=file, column=column)
    console.print(peter.not_null())

@app.command()
def is_unique(file: str = typer.Option(..., "--file", "-f"),
        column: str = typer.Option(None, "--column", "-c")):
    peter = CLIParquet(parquet_path=file, column=column)
    console.print(peter.is_unique())





if __name__ == "__main__":
    app()



import pyarrow.parquet as pq

class CLIParquet:
    def __init__(self, parquet_path, column = None):
        self.table = pq.read_table(parquet_path)
        self.file = pq.ParquetFile(parquet_path)

        if column is not None:
            self.column_index = self.table.column_names.index(column)
        else:
            self.column_index = None
            
    def metadata(self): 
        if self.column_index is not None:
            return self.file.metadata.row_group(0).column(self.column_index)
        else:
            return self.file.metadata

    def head(self, n = 5):
        if self.column_index is not None:
            return self.table.column(self.column_index)[0:n].to_pylist()
        else:
            return self.table[0:n].to_pylist()

    def tail(self, n = 5):
        if self.column_index is not None:
            return self.table.column(self.column_index)[-n:].to_pylist()
        else:
            return self.table[-n:].to_pylist()

    def cat(self):
        if self.column_index is not None:
            return self.table.column(self.column_index).to_pylist()
        else:
            return self.table.to_pylist()

    def schema(self):
        return self.table.schema

    def not_null(self) -> bool: 
        if self.column_index is None:
            print("Feature only available for single column.")
            return None
        else:
            not_null = True if self.table[self.column_index].null_count == 0 else False 
            return not_null

    def is_unique(self) -> bool:
        if self.column_index is None:
            print("Feature only available for single column.")
            return None
        else:
            total_rows = len(self.table[self.column_index])
            unique_rows = len(self.table[self.column_index].unique())
            return total_rows == unique_rows



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['peter_parquet']

package_data = \
{'': ['*']}

install_requires = \
['pyarrow[all]>=8.0.0,<9.0.0',
 'rich[all]>=12.4.4,<13.0.0',
 'typer[all]>=0.4.1,<0.5.0']

entry_points = \
{'console_scripts': ['peter-parquet = peter_parquet.main:app']}

setup_kwargs = {
    'name': 'peter-parquet',
    'version': '0.3.0',
    'description': '',
    'long_description': '# Peter Parquet\nQuickly inspect parquet file in command line\n\n# Where to get it\nThe source coid is currently hosted on Github at:\nBinary installers for the latest version are available at the repo\n\n```bash\npip install peter-parquet\n```\n\n# Usage\n`peter-parquet --help` return all commands available\n\n# Non Bash users\nIf you are a non Bash user, notice that Python package executables are installed to ~/.local/bin. So, make sure to add this entry to your PATH variable.\n\n',
    'author': 'sjlva',
    'author_email': 'rafaelsilva@posteo.net',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/sjlva/peter-parquet',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
